Serial
Serial communication through Elixir ports.
Summary
| break(pid) | Sends a break to the open connection |
| close(pid) | Close the currently open connection |
| connect(pid) | Reopens the connection to the current tty |
| disconnect(pid) | Disconnects from the current tty |
| open(pid, tty) | Opens a connection to the given tty |
| send_data(pid, data) | Sends data over the open connection |
| set_parity(pid, atom2) | Sets the parity to either |
| set_speed(pid, speed) | Sets the connection speed to the given value |
| set_speed(pid, in_speed, out_speed) | Sets the input and output connection speed to the given values |
| start_link(opts \\ []) | Starts a serial port. The process invoking this function will receive
messages in the form of |
Functions
Sends a break to the open connection.
Close the currently open connection.
Reopens the connection to the current tty.
Disconnects from the current tty.
Opens a connection to the given tty.
Sends data over the open connection.
Sets the parity to either :odd and :even.
Sets the connection speed to the given value.
Sets the input and output connection speed to the given values.
Starts a serial port. The process invoking this function will receive
messages in the form of {:elixir_serial, pid, data}.